@@ -163,7 +163,7 @@ impl BrokerStatement {
             statement.instrument_info.get_or_add(symbol).set_name(name);
         }
 
-        statement.validate()?;
+        statement.validate(strictness)?;
 
         process_corporate_actions(&mut statement)?;
         statement.process_trades(None)?;
@@ -294,7 +294,7 @@ impl BrokerStatement {
 
         let stock_sell = StockSell::new_trade(
             symbol, quantity, price, volume, commission,
-            conclusion_time, execution_date, false, true);
+            conclusion_time, execution_date, true);
 
         if let Entry::Occupied(mut open_position) = self.open_positions.entry(symbol.to_owned()) {
             let available = open_position.get_mut();
@@ -429,6 +429,7 @@ impl BrokerStatement {
         }
 
         self.fees.extend(statement.fees.into_iter());
+        self.cash_flows.extend(statement.cash_flows.into_iter());
         self.deposits_and_withdrawals.extend(statement.deposits_and_withdrawals.into_iter());
         self.idle_cash_interest.extend(statement.idle_cash_interest.into_iter());
         self.tax_agent_withholdings.extend(statement.tax_agent_withholdings.into_iter());
@@ -515,7 +516,7 @@ impl BrokerStatement {
         Ok(())
     }
 
-    fn validate(&mut self) -> EmptyResult {
+    fn validate(&mut self, strictness: ReadingStrictness) -> EmptyResult {
         let validator = DateValidator::new(self.period);
 
         validator.sort_and_validate(
@@ -525,6 +526,16 @@ impl BrokerStatement {
         self.sort_and_alter_fees(self.period.last_date());
         validator.validate("a fee", &self.fees, |fee| fee.date)?;
 
+        if
+            strictness.contains(ReadingStrictness::REPO_TRADES) &&
+            self.cash_flows.iter().any(|cash_flow| matches!(cash_flow.type_, CashFlowType::Repo{..}))
+        {
+            warn!(concat!(
+                "Broker statement contains repo trades which aren't supported yet. ",
+                "All repo trades will be ignored during the calculations."
+            ));
+        }
+
         self.cash_flows.sort_by(|a, b| a.sort_key().cmp(&b.sort_key()));
         validator.validate("a cash flow", &self.cash_flows, |cash_flow| cash_flow.date)?;
 
